==> ejc-purchasingmanagement-impl-3.0.0-20220613.033944-112-sources.jar: com/ejianc/business/purchasingmanagement/vo/MaterialacceptanceSummaryVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 材料验收汇总明细
 * 
 * @author generator
 * 
 */
public class MaterialacceptanceSummaryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long materialacceptanceId; // 材料验收主键
    private Long materialId; // 原材类品种主键
    private String materialName; // 原材类品种名称
    private BigDecimal price; // 单价
    private BigDecimal quantity; // 
    private BigDecimal materialTax; // 
    private BigDecimal freightRate; // 
    private Long materialplanId; // 定料计划主键
    private Long supplierinfoId; // 供应商基本档案主键
    private String supplierinfoName; // 供应商基本档案名称
    private String numberPlate; // 
    private Long shippersVehicleId; // 
    private String shippersVehicleName; // 
    private Long purchasereceiptId; // 
    private BigDecimal money; // 
    private Date receiptDate; // 
    private BigDecimal total; // 
    private BigDecimal materialTaxRate; // 
    

    public Long getMaterialacceptanceId() {
        return materialacceptanceId;
    }

    public void setMaterialacceptanceId(Long materialacceptanceId) {
        this.materialacceptanceId = materialacceptanceId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getMaterialTax() {
        return materialTax;
    }

    public void setMaterialTax(BigDecimal materialTax) {
        this.materialTax = materialTax;
    }
    public BigDecimal getFreightRate() {
        return freightRate;
    }

    public void setFreightRate(BigDecimal freightRate) {
        this.freightRate = freightRate;
    }
    public Long getMaterialplanId() {
        return materialplanId;
    }

    public void setMaterialplanId(Long materialplanId) {
        this.materialplanId = materialplanId;
    }
    public Long getSupplierinfoId() {
        return supplierinfoId;
    }

    public void setSupplierinfoId(Long supplierinfoId) {
        this.supplierinfoId = supplierinfoId;
    }
    public String getSupplierinfoName() {
        return supplierinfoName;
    }

    public void setSupplierinfoName(String supplierinfoName) {
        this.supplierinfoName = supplierinfoName;
    }
    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Long getShippersVehicleId() {
        return shippersVehicleId;
    }

    public void setShippersVehicleId(Long shippersVehicleId) {
        this.shippersVehicleId = shippersVehicleId;
    }
    public String getShippersVehicleName() {
        return shippersVehicleName;
    }

    public void setShippersVehicleName(String shippersVehicleName) {
        this.shippersVehicleName = shippersVehicleName;
    }
    public Long getPurchasereceiptId() {
        return purchasereceiptId;
    }

    public void setPurchasereceiptId(Long purchasereceiptId) {
        this.purchasereceiptId = purchasereceiptId;
    }
    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    public Date getReceiptDate() {
        return receiptDate;
    }

    public void setReceiptDate(Date receiptDate) {
        this.receiptDate = receiptDate;
    }
    public BigDecimal getTotal() {
        return total;
    }

    public void setTotal(BigDecimal total) {
        this.total = total;
    }
    public BigDecimal getMaterialTaxRate() {
        return materialTaxRate;
    }

    public void setMaterialTaxRate(BigDecimal materialTaxRate) {
        this.materialTaxRate = materialTaxRate;
    }
    
}

==> ejc-purchasingmanagement-impl-3.0.0-20220714.104004-159-sources.jar: com/ejianc/business/purchasingmanagement/vo/MaterialacceptanceSummaryVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 材料验收汇总明细
 * 
 * @author generator
 * 
 */
public class MaterialacceptanceSummaryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long materialacceptanceId; // 材料验收主键
    private Long materialId; // 合同子表主键
    private String materialName; // 合同子表原材类名称
    private BigDecimal price; // 含税单价
    private BigDecimal quantity; // 验收数量（收货卸车的净重）
    private BigDecimal materialTax; // 税额
    private BigDecimal freightRate; // 
    private Long materialplanId; // 定料计划主键
    private Long supplierinfoId; // 供应商基本档案主键
    private String supplierinfoName; // 供应商基本档案名称
    private String numberPlate; // 车牌号
    private Long shippersVehicleId; // 
    private String shippersVehicleName; // 
    private Long purchasereceiptId; // 收货卸车管理id
    private BigDecimal money; // 不含税金额
    private Date receiptDate; // 
    private BigDecimal total; //含税金额
    private BigDecimal materialTaxRate; // 税率
    private BigDecimal noTaxPrice; // 不含税单价
    

    public Long getMaterialacceptanceId() {
        return materialacceptanceId;
    }

    public void setMaterialacceptanceId(Long materialacceptanceId) {
        this.materialacceptanceId = materialacceptanceId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getMaterialTax() {
        return materialTax;
    }

    public void setMaterialTax(BigDecimal materialTax) {
        this.materialTax = materialTax;
    }
    public BigDecimal getFreightRate() {
        return freightRate;
    }

    public void setFreightRate(BigDecimal freightRate) {
        this.freightRate = freightRate;
    }
    public Long getMaterialplanId() {
        return materialplanId;
    }

    public void setMaterialplanId(Long materialplanId) {
        this.materialplanId = materialplanId;
    }
    public Long getSupplierinfoId() {
        return supplierinfoId;
    }

    public void setSupplierinfoId(Long supplierinfoId) {
        this.supplierinfoId = supplierinfoId;
    }
    public String getSupplierinfoName() {
        return supplierinfoName;
    }

    public void setSupplierinfoName(String supplierinfoName) {
        this.supplierinfoName = supplierinfoName;
    }
    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Long getShippersVehicleId() {
        return shippersVehicleId;
    }

    public void setShippersVehicleId(Long shippersVehicleId) {
        this.shippersVehicleId = shippersVehicleId;
    }
    public String getShippersVehicleName() {
        return shippersVehicleName;
    }

    public void setShippersVehicleName(String shippersVehicleName) {
        this.shippersVehicleName = shippersVehicleName;
    }
    public Long getPurchasereceiptId() {
        return purchasereceiptId;
    }

    public void setPurchasereceiptId(Long purchasereceiptId) {
        this.purchasereceiptId = purchasereceiptId;
    }
    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    public Date getReceiptDate() {
        return receiptDate;
    }

    public void setReceiptDate(Date receiptDate) {
        this.receiptDate = receiptDate;
    }
    public BigDecimal getTotal() {
        return total;
    }

    public void setTotal(BigDecimal total) {
        this.total = total;
    }
    public BigDecimal getMaterialTaxRate() {
        return materialTaxRate;
    }

    public void setMaterialTaxRate(BigDecimal materialTaxRate) {
        this.materialTaxRate = materialTaxRate;
    }

    public BigDecimal getNoTaxPrice() {
        return noTaxPrice;
    }

    public void setNoTaxPrice(BigDecimal noTaxPrice) {
        this.noTaxPrice = noTaxPrice;
    }
}
